@@ -28,7 +28,7 @@ gophertext(FILE *fp, const char *s)
 			fputs("        ", fp);
 			break;
 		default:
-			fputc(*s, fp);
+			putc(*s, fp);
 			break;
 		}
 	}
@@ -41,7 +41,7 @@ printfeed(FILE *fpitems, FILE *fpin, struct feed *f)
 	char *fields[FieldLast], *itemhost, *itemport, *itempath;
 	ssize_t linelen;
 	unsigned int isnew;
-	struct tm *tm;
+	struct tm rtm, *tm;
 	time_t parsedtime;
 	int itemtype;
 
@@ -81,7 +81,7 @@ printfeed(FILE *fpitems, FILE *fpin, struct feed *f)
 
 		parsedtime = 0;
 		if (!strtotime(fields[FieldUnixTimestamp], &parsedtime) &&
-		    (tm = localtime(&parsedtime))) {
+		    (tm = localtime_r(&parsedtime, &rtm))) {
 			isnew = (parsedtime >= comparetime) ? 1 : 0;
 			f->totalnew += isnew;
 
@@ -112,8 +112,17 @@ main(int argc, char *argv[])
 	char *name, *p, path[PATH_MAX + 1];
 	int i, r;
 
-	if (pledge(argc == 1 ? "stdio" : "stdio rpath wpath cpath", NULL) == -1)
-		err(1, "pledge");
+	if (argc == 1) {
+		if (pledge("stdio", NULL) == -1)
+			err(1, "pledge");
+	} else {
+		if (unveil("/", "r") == -1)
+			err(1, "unveil");
+		if (unveil(".", "rwc") == -1)
+			err(1, "unveil");
+		if (pledge("stdio rpath wpath cpath", NULL) == -1)
+			err(1, "pledge");
+	}
 
 	if ((comparetime = time(NULL)) == -1)
 		err(1, "time");
